@@ -1,5 +1,6 @@
 """Kameleoon PYTHON SDK"""
 
 from .sdk_version import __version__  # noqa: F401
-from .client import KameleoonClient  # noqa: F401
+from .kameleoon_client import KameleoonClient  # noqa: F401
+from .kameleoon_client_config import KameleoonClientConfig  # noqa: F401
 from .middleware import KameleoonWSGIMiddleware  # noqa: F401
