@@ -3,6 +3,7 @@
 
 from enum import Enum
 from kameleoon.data.data import Data, DataType
+from kameleoon.network.sendable import DuplicationUnsafeSendableBase
 from kameleoon.network.query_builder import QueryBuilder, QueryParam, QueryParams
 
 
@@ -14,7 +15,7 @@ class DeviceType(Enum):
     DESKTOP: str = "DESKTOP"
 
 
-class Device(Data):
+class Device(Data, DuplicationUnsafeSendableBase):
     """Device data"""
 
     EVENT_TYPE = "staticData"
@@ -28,14 +29,19 @@ class Device(Data):
                 kameleoon_client.add_data(visitor_code, Device(DeviceType.PHONE))
         """
         super().__init__()
-        self.device_type = device_type
-        self._instance: DataType = DataType.DEVICE
+        self.__device_type = device_type
 
-    def obtain_full_post_text_line(self) -> str:
-        return str(
-            QueryBuilder(
-                QueryParam(QueryParams.EVENT_TYPE, self.EVENT_TYPE),
-                QueryParam(QueryParams.DEVICE_TYPE, self.device_type.value),
-                QueryParam(QueryParams.NONCE, self._nonce),
-            )
+    @property
+    def device_type(self) -> DeviceType:
+        """Returns device type"""
+        return self.__device_type
+
+    @property
+    def data_type(self) -> DataType:
+        return DataType.DEVICE
+
+    def _add_query_params(self, qb: QueryBuilder) -> None:
+        qb.extend(
+            QueryParam(QueryParams.EVENT_TYPE, self.EVENT_TYPE),
+            QueryParam(QueryParams.DEVICE_TYPE, self.device_type.value),
         )
