@@ -1,7 +1,6 @@
 """Conversion condition"""
-from typing import Any, Dict, Optional, Union
-from kameleoon.data import Conversion, DataType
-
+from typing import Any, Dict, List, Union
+from kameleoon.data import Conversion
 from kameleoon.targeting.conditions.targeting_condition import TargetingCondition
 
 
@@ -15,9 +14,10 @@ class ConversionCondition(TargetingCondition):
         except KeyError as ex:
             self._logger.error("%s has wrong JSON structure: %s", self.__class__, ex)
 
-    def check(self, data) -> bool:
-        conversion: Optional[Conversion] = self.get_last_targeting_data(data, DataType.CONVERSION)
-        return conversion is not None and self.__goal_id in (
-            TargetingCondition.NON_EXISTENT_IDENTIFIER,
-            conversion.goal_id,
-        )
+    def check(self, data: Any) -> bool:
+        return isinstance(data, list) and self.__check(data)
+
+    def __check(self, conversions: List[Conversion]) -> bool:
+        # pylint: disable=R1706
+        return ((self.__goal_id == TargetingCondition.NON_EXISTENT_IDENTIFIER) and len(conversions) > 0) or \
+            any((isinstance(c, Conversion)) and (c.goal_id == self.__goal_id) for c in conversions)
