@@ -15,6 +15,7 @@ class PageTitleCondition(StringValueCondition):
 
     def __check(self, page_view_visits: Dict[str, PageViewVisit]) -> bool:
         return any(
-            isinstance(visit, PageViewVisit) and self._check(visit.page_view.title)
+            isinstance(visit, PageViewVisit) and visit.page_view.title is not None and self._check(
+                visit.page_view.title)
             for visit in page_view_visits.values()
         )
