@@ -1,4 +1,5 @@
 """Unknown condition"""
+from typing import Any
 from kameleoon.targeting.conditions.targeting_condition import TargetingCondition
 
 
@@ -9,5 +10,5 @@ class UnknownCondition(TargetingCondition):
     This condition always returns targeting result (True)
     """
 
-    def check(self, data) -> bool:
+    def check(self, data: Any) -> bool:
         return True
